/*
 * Copyright 2019-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opencord.bng.config;

import org.onosproject.core.ApplicationId;
import org.onosproject.net.DeviceId;
import org.onosproject.net.config.Config;

/**
 * Configuration of the BNG app.
 */
public class BngConfig extends Config<ApplicationId> {
    public static final String KEY = "bng";

    private static final String BNGU_DEVICE_ID = "bnguDeviceId";

    @Override
    public boolean isValid() {
        return hasOnlyFields(BNGU_DEVICE_ID) && hasField(BNGU_DEVICE_ID);
    }

    /**
     * Gets the BNG user plane device ID.
     *
     * @return BNG user plane device ID
     */
    public DeviceId getBnguDeviceId() {
        return DeviceId.deviceId(object.path(BNGU_DEVICE_ID).asText());
    }
}